HideBlizzard = LibStub('AceAddon-3.0'):NewAddon('HideBlizzard', 'AceConsole-3.0', 'AceEvent-3.0')
local CURRENT_VERSION = '1.0.51'
local ALPHA = 'Alpha'
local BETA = 'Beta'
local RELEASE = 'Release'
local RELEASE_TYPE = RELEASE

local defaults = {
	profile = {
		modules = {
			ActionBar = false,
			Buttons = false,
			Pet = false,
			Player = false,
			SpecialFrames = false,
			Target = false,
			Vehicle = false
		},
	}
}

HideBlizzard:SetDefaultModuleState(false)

function HideBlizzard:OnInitialize()
	self.db = LibStub('AceDB-3.0'):New('HideBlizzardDB', defaults)

	local timer, t = nil, 0
	function HideBlizzard:UpdateConfig()
		for k, v in self:IterateModules() do
			if v:IsEnabled() then
				v:Disable()
				v:Enable()
			end
		end
	end
	local function update()
		t = t + arg1
		if t > 0.5 then
			timer:SetScript('OnUpdate', nil)
			HideBlizzard:UpdateConfig()
		end
	end
	function HideBlizzard:OnProfileUpdate()
		t = 0
		timer = timer or CreateFrame('Frame', nil, UIParent)
		timer:SetScript('OnUpdate', update)
	end
end

function HideBlizzard:OnEnable()
	self:Welcome()
	self:Update()
	self:RegisterCommands()
	self:RegisterEvent('PLAYER_REGEN_DISABLED', function()
		if InterfaceOptionsFrame:IsVisible() then
			self:Print('Cannot configure settings while in combat. Closing options window.')
			InterfaceOptionsFrame:Hide()
		end
	end)

	for k, v in self:IterateModules() do
		if self.db.profile.modules[k] ~= false then
			v:Enable()
		end
	end

	StaticPopupDialogs['RESET_CONFIRM'] = {
		text = 'Are you sure you want to reset and reload ui?',
		button1 = 'Yes',
		button2 = 'No',
		OnAccept = function()
			wipe(HideBlizzardDB)
			ReloadUI()
		end,
		OnCancel = function()
			StaticPopup_Hide('RESET_CONFIRM')
		end,
		showAlert = 1,
		exclusive = 1,
		timeout = 0,
		whileDead = 1,
		hideOnEscape = 1,
	}

	self.db.RegisterCallback(self, 'OnProfileChanged', 'OnProfileUpdate')
	self.db.RegisterCallback(self, 'OnProfileCopied', 'OnProfileUpdate')
	self.db.RegisterCallback(self, 'OnProfileReset', 'OnProfileUpdate')
end

function HideBlizzard:OnDisable()
end

function HideBlizzard:Welcome()
	local lastUpdate = 0
	if not self.db.profile.Welcome then
		delay = delay or CreateFrame('Frame')
		delay:SetScript('OnUpdate', function(self, elapsed)
			lastUpdate = lastUpdate + elapsed
			if (lastUpdate > 5) then
				HideBlizzard:Print('Welcome! Type|r |cff40bbff/hb|r or |cff40bbff/hideblizzard|r to see the list of available commands.')
				HideBlizzard:Print('|cffff0000HideBlizzard was intended to be used with minimal (addons that dont modify blizzard frames) or without the use of any other addon(s) and cannot take responsibility with incompatibility issues that may surface from them.|r')
				HideBlizzard.db.profile.Welcome = true
				HideBlizzard.db.profile.Version = CURRENT_VERSION
				HideBlizzard.db.profile.ReleaseType = RELEASE_TYPE
				lastUpdate = 0
				delay:SetScript('OnUpdate', nil)
			end
		end)
	end
end

function HideBlizzard:Update()
	local lastUpdate = 0
	if self.db.profile.Version ~=  CURRENT_VERSION then
		if not self.db.profile.Welcome and not self.db.profile.Version and not self.db.profile.ReleaseType then
			return
		else
			delay = delay or CreateFrame('Frame')
			delay:SetScript('OnUpdate', function(self, elapsed)
				lastUpdate = lastUpdate + elapsed
				if (lastUpdate > 5) then
					if RELEASE_TYPE ~= RELEASE then
						HideBlizzard.db.profile.ReleaseType = RELEASE_TYPE
						HideBlizzard.db.profile.Version = CURRENT_VERSION
						HideBlizzard:Print(format('You are running a possibly buggy version of HideBlizzard |cffff0000(%s - %s)|r', HideBlizzard.db.profile.Version, HideBlizzard.db.profile.ReleaseType))
						HideBlizzard:Print('|cffff0000HideBlizzard was intended to be used with minimal (addons that dont modify blizzard frames) or without the use of any other addon(s) and cannot take responsibility with incompatibility issues that may surface from them.|r')
					else
						HideBlizzard.db.profile.ReleaseType = RELEASE_TYPE
						HideBlizzard.db.profile.Version = CURRENT_VERSION
						HideBlizzard:Print(format('Updated to version %s', HideBlizzard.db.profile.Version))
						HideBlizzard:Print('|cffff0000HideBlizzard was intended to be used with minimal (addons that dont modify blizzard frames) or without the use of any other addon(s) and cannot take responsibility with incompatibility issues that may surface from them.|r')
					end
					HideBlizzard:ShowChangelog()
					lastUpdate = 0
					delay:SetScript('OnUpdate', nil)
				end
			end)
		end
	end
end

function HideBlizzard:RegisterCommands()
	function HideBlizzard:Cmd(args)
		local cmd = string.split(' ', args):lower() or args:lower()
		local loaded = IsAddOnLoaded('HideBlizzardOptions')
		if cmd == 'config' then
			if not loaded then
				LoadAddOn('HideBlizzardOptions')
				self:RegisterOptions()
				InterfaceOptionsFrame_OpenToCategory(HideBlizzard.optionFrame.Profiles)
				InterfaceOptionsFrame_OpenToCategory(HideBlizzard.optionFrame.HideBlizzard)
			else
				InterfaceOptionsFrame_OpenToCategory(HideBlizzard.optionFrame.Profiles)
				InterfaceOptionsFrame_OpenToCategory(HideBlizzard.optionFrame.HideBlizzard)
			end
		elseif cmd == 'changelog' then
			self:ShowChangelog()
		elseif cmd == 'help' then
			self:ShowHelp()
		elseif cmd == 'reset' then
			StaticPopup_Show('RESET_CONFIRM')
		elseif cmd == 'version' then
			self:Print(format('Your current version is |cffff0000(%s - %s)|r', self.db.profile.Version, self.db.profile.ReleaseType))
		else
			self:CmdHelp()
		end
	end

	function HideBlizzard:CmdHelp(cmd)
		local function PrintCmd(cmd, desc)
			DEFAULT_CHAT_FRAME:AddMessage(format(' - |cff40bbff%s|r: %s', cmd, desc))
		end
		self:Print('Available Commands:')
		PrintCmd('changelog', 'opens the changlog window')
		PrintCmd('config', 'opens the option window')
		PrintCmd('help', 'opens the help window')
		PrintCmd('reset', 'resets the HideBlizzard database')
		PrintCmd('version', 'prints the current version and release type')
	end

	self:RegisterChatCommand('hb', 'Cmd')
	self:RegisterChatCommand('hideblizzard', 'Cmd')
end

function HideBlizzard:CheckClass(compared)
	local _, player = UnitClass('player')
	if player == compared then
		return false
	else
		return true
	end
end