-- Use // mod.db.profile // to interact with other options within the module
-- Use // HideBlizzard.db.profile.modules // to interact with main options

local mod = HideBlizzard:NewModule('ActionBar', 'AceEvent-3.0')
mod.modName = 'Action Bar'

local options = {
	gryphons = {
		type = 'toggle',
		name = 'Gryphons',
		width = 'full',
		get = function() return mod.db.profile.gryphons end,
		set = function(info, v)
			mod.db.profile.gryphons = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.ActionBar or mod.db.profile.mainmenubar end,
	},
	mainmenubar = {
		type = 'toggle',
		name = 'Main Menu Bar',
		width = 'full',
		get = function() return mod.db.profile.mainmenubar end,
		set = function(info, v)
			mod.db.profile.mainmenubar = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.ActionBar end,
	},
	repbar = {
		type = 'toggle',
		name = 'Rep Bar',
		width = 'full',
		get = function() return mod.db.profile.repbar end,
		set = function(info, v)
			mod.db.profile.repbar = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.ActionBar or mod.db.profile.mainmenubar end,
	},
	stancebar = {
		type = 'toggle',
		name = 'Stance Bar',
		width = 'full',
		get = function() return mod.db.profile.stancebar end,
		set = function(info, v)
			mod.db.profile.stancebar = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.ActionBar or mod.db.profile.mainmenubar or GetNumShapeshiftForms() == 0 end,
	},
	xpbar = {
		type = 'toggle',
		name = 'XP Bar',
		width = 'full',
		get = function() return mod.db.profile.xpbar end,
		set = function(info, v)
			mod.db.profile.xpbar = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.ActionBar or mod.db.profile.mainmenubar or UnitLevel('player') == MAX_PLAYER_LEVEL end,
	},
}

local defaults = {
	profile = {
		['*'] = false,
	},
}

function mod:OnInitialize()
	self.db = HideBlizzard.db:RegisterNamespace('ActionBar', defaults)
end

function mod:OnEnable()
	mod:UpdateFrames()
end

function mod:OnDisable()
	mod:UpdateFrames()
end

function mod:UpdateFrames()
	if mod.db.profile.gryphons == true and HideBlizzard.db.profile.modules.ActionBar == true then
		MainMenuBarLeftEndCap:Hide()
		MainMenuBarRightEndCap:Hide()
	else
		MainMenuBarLeftEndCap:Show()
		MainMenuBarRightEndCap:Show()
	end
	if mod.db.profile.mainmenubar == true and HideBlizzard.db.profile.modules.ActionBar == true then
		MainMenuBar:UnregisterAllEvents()
		MainMenuBar:Hide()
		MainMenuBar.Show = function() end
	else
		MainMenuBar.Show = nil
		MainMenuBar:Show()
		MainMenuBar:RegisterEvent('PLAYER_ENTERING_WORLD')
		MainMenuBar:RegisterEvent('ACTIONBAR_PAGE_CHANGED')
		MainMenuBar:RegisterEvent('ADDON_LOADED')
		MainMenuBar:RegisterEvent('BAG_UPDATE')
		MainMenuBar:RegisterEvent('UNIT_ENTERING_VEHICLE')
		MainMenuBar:RegisterEvent('UNIT_ENTERED_VEHICLE')
		MainMenuBar:RegisterEvent('UNIT_EXITING_VEHICLE')
		MainMenuBar:RegisterEvent('UNIT_EXITED_VEHICLE')
	end
	if mod.db.profile.repbar == true and HideBlizzard.db.profile.modules.ActionBar == true then
		for factionIndex = 1, GetNumFactions() do
			local isWatched = GetFactionInfo(factionIndex)
			if isWatched then
				RegisterStateDriver(ReputationWatchBar, 'visibility', 'hide')
				ReputationWatchBar.Show = function() end
			else
				RegisterStateDriver(ReputationWatchBar, 'visibility', 'hide')
				ReputationWatchBar.Show = function() end
			end
		end
	else
		for factionIndex = 1, GetNumFactions() do
			local isWatched = GetFactionInfo(factionIndex)
			if isWatched then
				ReputationWatchBar.Show = nil
				RegisterStateDriver(ReputationWatchBar, 'visibility', 'show')
				SecureStateDriverManager:SetAttribute('delframe', ReputationWatchBar)
				ReputationWatchBar_Update()
			else
				RegisterStateDriver(ReputationWatchBar, 'visibility', 'hide')
				ReputationWatchBar.Show = function() end
				ReputationWatchBar_Update()
			end
		end
	end
	if mod.db.profile.stancebar == true and HideBlizzard.db.profile.modules.ActionBar == true then
		if GetNumShapeshiftForms() ~= 0 then
			RegisterStateDriver(ShapeshiftBarFrame, 'visibility', 'hide')
			ShapeshiftBarFrame.Show = function() end
		end
	else
		if GetNumShapeshiftForms() ~= 0 then
			ShapeshiftBarFrame.Show = nil
			RegisterStateDriver(ShapeshiftBarFrame, 'visibility', 'show')
			SecureStateDriverManager:SetAttribute('delframe', ShapeshiftBarFrame)
		end
	end
	if mod.db.profile.xpbar == true and HideBlizzard.db.profile.modules.ActionBar == true then
		RegisterStateDriver(MainMenuExpBar, 'visibility', 'hide')
		MainMenuExpBar.Show = function() end
	else
		MainMenuExpBar.Show = nil
		RegisterStateDriver(MainMenuExpBar, 'visibility', 'show')
		SecureStateDriverManager:SetAttribute('delframe', MainMenuExpBar)
	end
end

function mod:Info()
	return 'Hides frames connected to the main action bar.'
end

function mod:GetOptions()
	return options
end