-- Use // mod.db.profile // to interact with other options within the module
-- Use // HideBlizzard.db.profile.modules // to interact with main options

local mod = HideBlizzard:NewModule('Buttons', 'AceEvent-3.0')
mod.modName = 'Buttons'

local options = {
	chatbuttons = {
		type = 'toggle',
		name = 'Chat Buttons',
		width = 'full',
		get = function() return mod.db.profile.chatbuttons end,
		set = function(info, v)
			mod.db.profile.chatbuttons = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Buttons end,
	},
	battleground = {
		type = 'toggle',
		name = 'Battleground',
		width = 'full',
		get = function() return mod.db.profile.battleground end,
		set = function(info, v)
			mod.db.profile.battleground = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Buttons end,
	},
	calendar = {
		type = 'toggle',
		name = 'Calendar',
		width = 'full',
		get = function() return mod.db.profile.calendar end,
		set = function(info, v)
			mod.db.profile.calendar = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Buttons end,
	},
	mail = {
		type = 'toggle',
		name = 'Mail',
		width = 'full',
		get = function() return mod.db.profile.mail end,
		set = function(info, v)
			mod.db.profile.mail = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Buttons end,
	},
	tracking = {
		type = 'toggle',
		name = 'Tracking',
		width = 'full',
		get = function() return mod.db.profile.tracking end,
		set = function(info, v)
			mod.db.profile.tracking = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Buttons end,
	},
	voice = {
		type = 'toggle',
		name = 'Voice',
		width = 'full',
		get = function() return mod.db.profile.voice end,
		set = function(info, v)
			mod.db.profile.voice = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Buttons end,
	},
	world = {
		type = 'toggle',
		name = 'World Map',
		width = 'full',
		get = function() return mod.db.profile.world end,
		set = function(info, v)
			mod.db.profile.world = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Buttons end,
	},
	zoom = {
		type = 'toggle',
		name = 'Zoom',
		width = 'full',
		get = function() return mod.db.profile.zoom end,
		set = function(info, v)
			mod.db.profile.zoom = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Buttons end,
	},
}

local defaults = {
	profile = {
		['*'] = false,
	},
}

function mod:OnInitialize()
	self.db = HideBlizzard.db:RegisterNamespace('Buttons', defaults)
end

function mod:OnEnable()
	mod:UpdateFrames()
end

function mod:OnDisable()
	mod:UpdateFrames()
end

function mod:UpdateFrames()
	if mod.db.profile.chatbuttons == true and HideBlizzard.db.profile.modules.Buttons == true then
		ChatFrameMenuButton:Hide()
		for i = 1, NUM_CHAT_WINDOWS do
			local up = _G['ChatFrame'..i..'UpButton']
			up:Hide()
			up.Show = function() end
			local down = _G['ChatFrame'..i..'DownButton']
			down:Hide()
			down.Show = function() end
			local bottom = _G['ChatFrame'..i..'BottomButton']
			bottom:Hide()
			bottom.Show = function() end
		end
	else
		ChatFrameMenuButton:Show()
		for i = 1, NUM_CHAT_WINDOWS do
			local up = _G['ChatFrame'..i..'UpButton']
			up.Show = nil
			up:Show()
			local down = _G['ChatFrame'..i..'DownButton']
			down.Show = nil
			down:Show()
			local bottom = _G['ChatFrame'..i..'BottomButton']
			bottom.Show = nil
			bottom:Show()
		end
	end
	if mod.db.profile.battleground == true and HideBlizzard.db.profile.modules.Buttons == true then
		MiniMapBattlefieldFrame:UnregisterAllEvents()
		MiniMapBattlefieldFrame:Hide()
	else
		BattlefieldFrame_UpdateStatus()
	end
	if mod.db.profile.calendar == true and HideBlizzard.db.profile.modules.Buttons == true then
		GameTimeFrame:UnregisterAllEvents()
		GameTimeFrame:Hide()
	else
		GameTimeFrame:Show()
		GameTimeFrame:RegisterEvent('PLAYER_ENTERING_WORLD')
		GameTimeFrame:RegisterEvent('CALENDAR_UPDATE_PENDING_INVITES')
		GameTimeFrame:RegisterEvent('CALENDAR_EVENT_ALARM')
	end
	if mod.db.profile.mail == true and HideBlizzard.db.profile.modules.Buttons == true then
		MiniMapMailFrame:UnregisterAllEvents()
		MiniMapMailFrame:Hide()
	else
		if HasNewMail() then
			MiniMapMailFrame:Show()
		else
			MiniMapMailFrame:Hide()
		end
	end
	if mod.db.profile.tracking == true and HideBlizzard.db.profile.modules.Buttons == true then
		MiniMapTracking:UnregisterAllEvents()
		MiniMapTrackingButton:Hide()
		MiniMapTrackingIcon:Hide()
		MiniMapTrackingBackground:Hide()
	else
		MiniMapTrackingButton:Show()
		MiniMapTrackingIcon:Show()
		MiniMapTrackingBackground:Show()
		MiniMapTrackingButton:RegisterEvent('MINIMAP_UPDATE_TRACKING')
	end
	if mod.db.profile.voice == true and HideBlizzard.db.profile.modules.Buttons == true then
		MiniMapVoiceChatFrame:UnregisterAllEvents()
		MiniMapVoiceChatFrame:Hide()
	else
		MiniMapVoiceChat_Update()
	end
	if mod.db.profile.world == true and HideBlizzard.db.profile.modules.Buttons == true then
		MiniMapWorldMapButton:Hide() 
	else
		MiniMapWorldMapButton:Show()
	end
	if mod.db.profile.zoom == true and HideBlizzard.db.profile.modules.Buttons == true then
		MinimapZoomIn:Hide()
		MinimapZoomOut:Hide()
	else
		MinimapZoomIn:Show()
		MinimapZoomOut:Show()
	end
end

function mod:Info()
	return 'Hides buttons connected to the chat and minimap frame.'
end

function mod:GetOptions()
	return options
end