-- Use // mod.db.profile // to interact with other options within the module
-- Use // HideBlizzard.db.profile.modules // to interact with main options

local mod = HideBlizzard:NewModule('Pet', 'AceEvent-3.0')
mod.modName = 'Pet'

local options = {
	petactionbar = {
		type = 'toggle',
		name = 'Pet Action Bar',
		width = 'full',
		get = function() return mod.db.profile.petactionbar end,
		set = function(info, v)
			mod.db.profile.petactionbar = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Pet end,
	},
	petcastbar = {
		type = 'toggle',
		name = 'Pet Cast Bar',
		width = 'full',
		get = function() return mod.db.profile.petcastbar end,
		set = function(info, v)
			mod.db.profile.petcastbar = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Pet end,
	},
	pethappyframe = {
		type = 'toggle',
		name = 'Pet Happiness Frame',
		width = 'full',
		get = function() return mod.db.profile.pethappyframe end,
		set = function(info, v)
			mod.db.profile.pethappyframe = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Pet or mod.db.profile.petunitframe end,
	},
	petunitframe = {
		type = 'toggle',
		name = 'Pet Unit Frame',
		width = 'full',
		get = function() return mod.db.profile.petunitframe end,
		set = function(info, v)
			mod.db.profile.petunitframe = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Pet end,
	},
}

local defaults = {
	profile = {
		['*'] = false,
	},
}

function mod:OnInitialize()
	self.db = HideBlizzard.db:RegisterNamespace('Pet', defaults)
end

function mod:OnEnable()
	mod:UpdateFrames()
end

function mod:OnDisable()
	mod:UpdateFrames()
end

function mod:UpdateFrames()
	if mod.db.profile.petactionbar == true and HideBlizzard.db.profile.modules.Pet == true then
		PetActionBarFrame:UnregisterAllEvents()
		PetActionBarFrame:Hide()
	else
		if UnitExists('pet') then
			PetActionBarFrame:Show()
		end
		PetActionBarFrame:RegisterEvent('PLAYER_CONTROL_LOST')
		PetActionBarFrame:RegisterEvent('PLAYER_CONTROL_GAINED')
		PetActionBarFrame:RegisterEvent('PLAYER_FARSIGHT_FOCUS_CHANGED')
		PetActionBarFrame:RegisterEvent('UNIT_PET')
		PetActionBarFrame:RegisterEvent('UNIT_FLAGS')
		PetActionBarFrame:RegisterEvent('UNIT_AURA')
		PetActionBarFrame:RegisterEvent('PET_BAR_UPDATE')
		PetActionBarFrame:RegisterEvent('PET_BAR_UPDATE_COOLDOWN')
		PetActionBarFrame:RegisterEvent('PET_BAR_SHOWGRID')
		PetActionBarFrame:RegisterEvent('PET_BAR_HIDEGRID')
		PetActionBarFrame:RegisterEvent('PET_BAR_HIDE')
	end
	if mod.db.profile.petcastbar == true and HideBlizzard.db.profile.modules.Pet == true then
		PetCastingBarFrame:UnregisterAllEvents()
		PetCastingBarFrame:Hide()
	else
		PetCastingBarFrame:RegisterEvent('UNIT_SPELLCAST_START')
		PetCastingBarFrame:RegisterEvent('UNIT_SPELLCAST_STOP')
		PetCastingBarFrame:RegisterEvent('UNIT_SPELLCAST_FAILED')
		PetCastingBarFrame:RegisterEvent('UNIT_SPELLCAST_INTERRUPTED')
		PetCastingBarFrame:RegisterEvent('UNIT_SPELLCAST_DELAYED')
		PetCastingBarFrame:RegisterEvent('UNIT_SPELLCAST_CHANNEL_START')
		PetCastingBarFrame:RegisterEvent('UNIT_SPELLCAST_CHANNEL_UPDATE')
		PetCastingBarFrame:RegisterEvent('PLAYER_ENTERING_WORLD')
		PetCastingBarFrame:RegisterEvent('UNIT_PET')
	end
	if mod.db.profile.pethappyframe == true and HideBlizzard.db.profile.modules.Pet == true then
		PetFrameHappiness:Hide()
		PetFrameHappiness.Show = function() end
	else
		if UnitExists('pet') then
			PetFrameHappiness.Show = nil
			PetFrameHappiness:Show()
		end
	end
	if mod.db.profile.petunitframe == true and HideBlizzard.db.profile.modules.Pet == true then
		PetFrame:UnregisterAllEvents()
		PetFrame:Hide()
		PetFrame.Show = function() end
	else
		if UnitExists('pet') then
			PetFrame.Show = nil
			PetFrame:Show()
		end
		PetFrame:RegisterEvent('UNIT_PET')
		PetFrame:RegisterEvent('UNIT_COMBAT')
		PetFrame:RegisterEvent('UNIT_AURA')
		PetFrame:RegisterEvent('PET_ATTACK_START')
		PetFrame:RegisterEvent('PET_ATTACK_STOP')
		PetFrame:RegisterEvent('UNIT_HAPPINESS')
		PetFrame:RegisterEvent('PET_UI_UPDATE')
		PetFrame:RegisterEvent('PET_RENAMEABLE')
	end
end

function mod:Info()
	return 'Hides pet related frames.'
end

function mod:GetOptions()
	return options
end