-- Use // mod.db.profile // to interact with other options within the module
-- Use // HideBlizzard.db.profile.modules // to interact with main options

local mod = HideBlizzard:NewModule('Player', 'AceEvent-3.0')
mod.modName = 'Player'

local options = {
	armoredman = {
		type = 'toggle',
		name = 'Armored Man',
		width = 'full',
		get = function() return mod.db.profile.armoredman end,
		set = function(info, v)
			mod.db.profile.armoredman = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Player end,
	},
	aura = {
		type = 'toggle',
		name = 'Aura',
		width = 'full',
		get = function() return mod.db.profile.aura end,
		set = function(info, v)
			mod.db.profile.aura = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Player end,
	},
	druidmanabar = {
		type = 'toggle',
		name = 'Druid Mana Bar',
		width = 'full',
		get = function() return mod.db.profile.druidmanabar end,
		set = function(info, v)
			mod.db.profile.druidmanabar = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Player or HideBlizzard:CheckClass('DRUID') end,
	},
	playercastbar = {
		type = 'toggle',
		name = 'Player Cast Bar',
		width = 'full',
		get = function() return mod.db.profile.playercastbar end,
		set = function(info, v)
			mod.db.profile.playercastbar = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Player end,
	},
	playerunitframe = {
		type = 'toggle',
		name = 'Player Unit Frame',
		width = 'full',
		get = function() return mod.db.profile.playerunitframe end,
		set = function(info, v)
			mod.db.profile.playerunitframe = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Player end,
	},
	runeframe = {
		type = 'toggle',
		name = 'Rune Frame',
		width = 'full',
		get = function() return mod.db.profile.runeframe end,
		set = function(info, v)
			mod.db.profile.runeframe = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Player or HideBlizzard:CheckClass('DEATHKNIGHT') end,
	},
	totemframe = {
		type = 'toggle',
		name = 'Totem Frame',
		width = 'full',
		get = function() return mod.db.profile.totemframe end,
		set = function(info, v)
			mod.db.profile.totemframe = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Player or HideBlizzard:CheckClass('SHAMAN') end,
	},
}

local defaults = {
	profile = {
		['*'] = false,
	},
}

function mod:OnInitialize()
	self.db = HideBlizzard.db:RegisterNamespace('Player', defaults)
end

function mod:OnEnable()
	mod:UpdateFrames()
end

function mod:OnDisable()
	mod:UpdateFrames()
end

function mod:UpdateFrames()
	if mod.db.profile.armoredman == true and HideBlizzard.db.profile.modules.Player == true then
		DurabilityFrame:UnregisterAllEvents()
		DurabilityFrame:Hide() 
	else
		DurabilityFrame:RegisterEvent('UNIT_INVENTORY_CHANGED')
		DurabilityFrame:RegisterEvent('UPDATE_INVENTORY_ALERTS')
	end
	if mod.db.profile.aura == true and HideBlizzard.db.profile.modules.Player == true then
		BuffFrame:UnregisterAllEvents()
		BuffFrame:Hide()
		TemporaryEnchantFrame:Hide()
	else
		TemporaryEnchantFrame:Show()
		BuffFrame:Show()
		BuffFrame:RegisterEvent('UNIT_AURA')
		BuffFrame:RegisterEvent('PLAYER_AURAS_CHANGED')
		BuffFrame_Update()
	end
	if mod.db.profile.druidmanabar == true and HideBlizzard.db.profile.modules.Player == true then
		for shapeshiftIndex = 1, GetNumShapeshiftForms() do
			local active = GetShapeshiftFormInfo(shapeshiftIndex)
			if active then
				PlayerFrameAlternateManaBar:UnregisterAllEvents()
				PlayerFrameAlternateManaBar:Hide()
				PlayerFrameAlternateManaBar.Show = function() end
			else
				PlayerFrameAlternateManaBar:UnregisterAllEvents()
				PlayerFrameAlternateManaBar:Hide()
				PlayerFrameAlternateManaBar.Show = function() end
			end
		end
	else
		for shapeshiftIndex = 1, GetNumShapeshiftForms() do
			local active = GetShapeshiftFormInfo(shapeshiftIndex)
			if active then
				PlayerFrameAlternateManaBar.Show = nil
				PlayerFrameAlternateManaBar:Show()
				PlayerFrameAlternateManaBar:RegisterEvent('PLAYER_ENTERING_WORLD')
				PlayerFrameAlternateManaBar:RegisterEvent('UNIT_DISPLAYPOWER')
				PlayerFrameAlternateManaBar:RegisterEvent('UNIT_MAXMANA')
				PlayerFrameAlternateManaBar:RegisterEvent('UNIT_MANA')
				AlternatePowerBar_UpdateValue(PlayerFrameAlternateManaBar)
				AlternatePowerBar_UpdateMaxValues(PlayerFrameAlternateManaBar)
				AlternatePowerBar_UpdatePowerType(PlayerFrameAlternateManaBar)
			else
				PlayerFrameAlternateManaBar:Hide()
				PlayerFrameAlternateManaBar.Show = function() end
			end
		end
	end
	if mod.db.profile.playercastbar == true and HideBlizzard.db.profile.modules.Player == true then
		CastingBarFrame:UnregisterAllEvents()
		CastingBarFrame:Hide()
	else
		CastingBarFrame:RegisterEvent('UNIT_SPELLCAST_START')
		CastingBarFrame:RegisterEvent('UNIT_SPELLCAST_STOP')
		CastingBarFrame:RegisterEvent('UNIT_SPELLCAST_FAILED')
		CastingBarFrame:RegisterEvent('UNIT_SPELLCAST_INTERRUPTED')
		CastingBarFrame:RegisterEvent('UNIT_SPELLCAST_DELAYED')
		CastingBarFrame:RegisterEvent('UNIT_SPELLCAST_CHANNEL_START')
		CastingBarFrame:RegisterEvent('UNIT_SPELLCAST_CHANNEL_UPDATE')
		CastingBarFrame:RegisterEvent('PLAYER_ENTERING_WORLD')
	end
	if mod.db.profile.playerunitframe == true and HideBlizzard.db.profile.modules.Player == true then
		PlayerFrame:UnregisterAllEvents()
		PlayerFrameHealthBar:UnregisterAllEvents()
		PlayerFrameManaBar:UnregisterAllEvents()
		PlayerFrame:Hide()
	else
		PlayerFrame:RegisterEvent('UNIT_LEVEL')
		PlayerFrame:RegisterEvent('UNIT_COMBAT')
		PlayerFrame:RegisterEvent('UNIT_SPELLMISS')
		PlayerFrame:RegisterEvent('UNIT_PVP_UPDATE')
		PlayerFrame:RegisterEvent('UNIT_MAXMANA')
		PlayerFrame:RegisterEvent('PLAYER_ENTER_COMBAT')
		PlayerFrame:RegisterEvent('PLAYER_LEAVE_COMBAT')
		PlayerFrame:RegisterEvent('PLAYER_UPDATE_RESTING')
		PlayerFrame:RegisterEvent('PARTY_MEMBERS_CHANGED')
		PlayerFrame:RegisterEvent('PARTY_LEADER_CHANGED')
		PlayerFrame:RegisterEvent('PARTY_LOOT_METHOD_CHANGED')
		PlayerFrame:RegisterEvent('PLAYER_ENTERING_WORLD')
		PlayerFrame:RegisterEvent('PLAYER_REGEN_DISABLED')
		PlayerFrame:RegisterEvent('PLAYER_REGEN_ENABLED')
		PlayerFrameHealthBar:RegisterEvent('UNIT_HEALTH')
		PlayerFrameHealthBar:RegisterEvent('UNIT_MAXHEALTH')
		PlayerFrameManaBar:RegisterEvent('UNIT_MANA')
		PlayerFrameManaBar:RegisterEvent('UNIT_RAGE')
		PlayerFrameManaBar:RegisterEvent('UNIT_FOCUS')
		PlayerFrameManaBar:RegisterEvent('UNIT_ENERGY')
		PlayerFrameManaBar:RegisterEvent('UNIT_RUNIC_POWER')
		PlayerFrameManaBar:RegisterEvent('UNIT_HAPPINESS')
		PlayerFrameManaBar:RegisterEvent('UNIT_MAXMANA')
		PlayerFrameManaBar:RegisterEvent('UNIT_MAXRAGE')
		PlayerFrameManaBar:RegisterEvent('UNIT_MAXFOCUS')
		PlayerFrameManaBar:RegisterEvent('UNIT_MAXENERGY')
		PlayerFrameManaBar:RegisterEvent('UNIT_MAXRUNIC_POWER')
		PlayerFrameManaBar:RegisterEvent('UNIT_MAXHAPPINESS')
		PlayerFrameManaBar:RegisterEvent('UNIT_RUNIC_POWER')
		PlayerFrameManaBar:RegisterEvent('UNIT_DISPLAYPOWER')
		PlayerFrame:RegisterEvent('UNIT_NAME_UPDATE')
		PlayerFrame:RegisterEvent('UNIT_PORTRAIT_UPDATE')
		PlayerFrame:RegisterEvent('UNIT_DISPLAYPOWER')
		PlayerFrame:Show()
		PlayerFrame_Update()
	end
	if mod.db.profile.runeframe == true and HideBlizzard.db.profile.modules.Player == true then
		local _, class = UnitClass('player')
		if (class == 'DEATHKNIGHT') then
			RuneFrame:UnregisterAllEvents()
			RuneFrame:Hide()
		end
	else
		local _, class = UnitClass('player')
		if (class == 'DEATHKNIGHT') then
			RuneFrame:Show()
			RuneFrame:RegisterEvent('RUNE_POWER_UPDATE')
			RuneFrame:RegisterEvent('RUNE_TYPE_UPDATE')
			RuneFrame:RegisterEvent('UNIT_RUNIC_POWER')
			RuneFrame:RegisterEvent('UNIT_MAXRUNIC_POWER')
			RuneFrame:RegisterEvent('PLAYER_ENTERING_WORLD')
		end
	end
	if mod.db.profile.totemframe == true and HideBlizzard.db.profile.modules.Player == true then
		local _, class = UnitClass('player')
		if (class == 'SHAMAN') then
			for i = 1, MAX_TOTEMS do
				local totem = _G['TotemFrameTotem'..i]
				totem:UnregisterAllEvents()
				totem:Hide()
				totem.Show = function() end
			end
		end
	else
		local _, class = UnitClass('player')
		if (class == 'SHAMAN') then
			for i = 1, MAX_TOTEMS do
				local totem = _G['TotemFrameTotem'..i]
				totem.Show = nil
				totem:RegisterEvent('PLAYER_TOTEM_UPDATE')
				totem:RegisterEvent('PLAYER_ENTERING_WORLD')
				totem:RegisterForClicks('RightButtonUp')
				TotemFrame_Update()
			end
		end
	end
end

function mod:Info()
	return 'Hides player related frames.'
end

function mod:GetOptions()
	return options
end