-- Use // mod.db.profile // to interact with other options within the module
-- Use // HideBlizzard.db.profile.modules // to interact with main options

local mod = HideBlizzard:NewModule('Vehicle', 'AceEvent-3.0')
mod.modName = 'Vehicle'

local options = {
	vehiclemenubar = {
		type = 'toggle',
		name = 'Vehicle Menu Bar',
		width = 'full',
		get = function() return mod.db.profile.vehiclemenubar end,
		set = function(info, v)
			mod.db.profile.vehiclemenubar = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Vehicle end,
	},
	vehicleseat = {
		type = 'toggle',
		name = 'Vehicle Seat', 
		width = 'full',
		get = function() return mod.db.profile.vehicleseat end,
		set = function(info, v)
			mod.db.profile.vehicleseat = v
			mod:UpdateFrames()
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Vehicle end,
	},
}

local defaults = {
	profile = {
		['*'] = false,
	},
}

function mod:OnInitialize()
	self.db = HideBlizzard.db:RegisterNamespace('Vehicle', defaults)
end

function mod:OnEnable()
	mod:UpdateFrames()
end

function mod:OnDisable()
	mod:UpdateFrames()
end

function mod:UpdateFrames()
	if mod.db.profile.vehiclemenubar == true and HideBlizzard.db.profile.modules.Vehicle == true then
		VehicleMenuBar:UnregisterAllEvents()
		VehicleMenuBar:Hide()
		VehicleMenuBar.Show = function() end
	else
		if UnitInVehicle('player') then
			VehicleMenuBar.Show = nil
			VehicleMenuBar:Show()
		end
		VehicleMenuBar:RegisterEvent('UNIT_ENTERING_VEHICLE')
		VehicleMenuBar:RegisterEvent('UNIT_ENTERED_VEHICLE')
		VehicleMenuBar:RegisterEvent('UNIT_EXITED_VEHICLE')
		VehicleMenuBar:RegisterEvent('UNIT_DISPLAYPOWER')
		VehicleMenuBar:RegisterEvent('VEHICLE_ANGLE_UPDATE')
		VehicleMenuBar:RegisterEvent('VEHICLE_PASSENGERS_CHANGED')
		VehicleMenuBar:RegisterEvent('PLAYER_GAINS_VEHICLE_DATA')
		VehicleMenuBar:RegisterEvent('PLAYER_LOSES_VEHICLE_DATA')
		VehicleMenuBar:RegisterEvent('PLAYER_ENTERING_WORLD')
	end
	if mod.db.profile.vehicleseat == true and HideBlizzard.db.profile.modules.Vehicle == true then
		VehicleSeatIndicator:UnregisterAllEvents()
		VehicleSeatIndicator:Hide()
		VehicleSeatIndicator.Show = function() end
	else
		if UnitInVehicle('player') then
			VehicleSeatIndicator.Show = nil
			VehicleSeatIndicator:Show()
		end
		VehicleSeatIndicator:RegisterEvent('UNIT_ENTERING_VEHICLE')
		VehicleSeatIndicator:RegisterEvent('UNIT_ENTERED_VEHICLE')
		VehicleSeatIndicator:RegisterEvent('UNIT_EXITED_VEHICLE')
		VehicleSeatIndicator:RegisterEvent('UNIT_DISPLAYPOWER')
		VehicleSeatIndicator:RegisterEvent('VEHICLE_ANGLE_UPDATE')
		VehicleSeatIndicator:RegisterEvent('VEHICLE_PASSENGERS_CHANGED')
		VehicleSeatIndicator:RegisterEvent('PLAYER_GAINS_VEHICLE_DATA')
		VehicleSeatIndicator:RegisterEvent('PLAYER_LOSES_VEHICLE_DATA')
		VehicleSeatIndicator:RegisterEvent('PLAYER_ENTERING_WORLD')
	end
end

function mod:Info()
	return 'Hides vehicle related frames.'
end

function mod:GetOptions()
	return options
end