local version = HideBlizzard.db.profile.Version

local options = {
	type = 'group',
	args = {
		main = {
			type = 'group',
			name = 'HideBlizzard',
			args = {
				intro = {
					type = 'description',
					order = 1,
					name = 'HideBlizzard lets you hide blizzard frames located on the interface. You can toggle any of the available frames listed to hide them. The settings are saved per-character so you can have individual settings for each of them.\n\n|cffff0000HideBlizzard was intended to be used with minimal (addons that dont modify blizzard frames) or without the use of any other addon(s) and cannot take responsibility with incompatibility issues that may surface from them.|r\n',
				},
				help = {
					type = 'execute',
					order = 2,
					name = 'Help!',
					desc = 'Open the help dialog',
					func = function()
						HideBlizzard:ShowHelp()
					end,
				},
				changelog = {
					type = 'execute',
					order = 3,
					name = 'Changelog',
					desc = 'View the changes in HideBlizzard',
					func = function()
						HideBlizzard:ShowChangelog()
					end,
				},
				reset = {
					type = 'execute',
					order = 4,
					name = 'Reset',
					desc = 'Reset settings to defaults',
					func = function()
						StaticPopup_Show('RESET_CONFIRM')
					end,
				},
				fixme = {
					type = 'execute',
					order = 5,
					name = 'Fix Me!',
					desc = 'This will try to fix a problem within HideBlizzard. An alternative to using the reset button\n\n|cffff0000CURRENTLY DOES NOTHING|r',
					func = function()
						
					end,
				},
			},
		},
		modules = {
			type = 'group',
			name = 'Modules',
			desc = 'Modules',
			args = {}
		},
	},
}

function HideBlizzard:RegisterOptions()
	self.optionFrame = {}

	LibStub('AceConfigRegistry-3.0'):RegisterOptionsTable('HideBlizzard', options)
	LibStub('AceConfigRegistry-3.0'):RegisterOptionsTable('HideBlizzardModules', options.args.modules)
	self.optionFrame.HideBlizzard = LibStub('AceConfigDialog-3.0'):AddToBlizOptions('HideBlizzard', nil, nil, 'main')

	if not options.args.Profiles then
		options.args.Profiles = LibStub('AceDBOptions-3.0'):GetOptionsTable(self.db)
		self.optionFrame.Profiles = LibStub('AceConfigDialog-3.0'):AddToBlizOptions('HideBlizzard', 'Profiles', 'HideBlizzard', 'Profiles')
	end

	for k, v in self:IterateModules() do
		options.args.modules.args[k:gsub(' ', '_')] = {
			type = 'group',
			name = (v.modName or k),
			args = nil
		}
		local t
		if v.GetOptions then
			t = v:GetOptions()
			t.settingsHeader = {
				type = 'header',
				name = 'Settings',
				order = 12,
			}
		end
		t = t or {}
		t.toggle = {
			type = 'toggle',
			name = v.toggleLabel or ('Enable '..(v.modName or k)),
			order = 11,
			get = function()
				return HideBlizzard.db.profile.modules[k] ~= false or false
			end,
			set = function(info, v)
				HideBlizzard.db.profile.modules[k] = v
				if v then
					HideBlizzard:EnableModule(k)
				else
					HideBlizzard:DisableModule(k)
				end
			end,
		}
		if v.Info then
			t.description = {
				type = 'description',
				name = v:Info()..'\n\n',
				order = 10,
			}
		end
		options.args.modules.args[k:gsub(' ', '_')].args = t
	end

	local moduleList = {}
	local moduleNames = {}
	for k, v in pairs(options.args.modules.args) do
		moduleList[v.name] = k
		table.insert(moduleNames, v.name)
	end
	table.sort(moduleNames)
	for _, name in ipairs(moduleNames) do
		LibStub('AceConfigDialog-3.0'):AddToBlizOptions('HideBlizzardModules', name, 'HideBlizzard', moduleList[name])
	end
end